/*
*******************************
The code was prepared by the Institute for Structural Research - IBS.
In case of using it please include the following citation:

Hardy, W., Keister, R. and Lewandowski, P. (2016). Do Entrants Take It All? The Evolution of Task Content of Jobs in Poland. Ekonomia. Rynek, Gospodarka, Społeczeństwo 47.

For details, you can find the paper here: http://ekonomia.wne.uw.edu.pl/ekonomia/getFile/799
*******************************

*******************************
This code was written for Stata 12 but should work for other versions without any or any major changes.
*******************************
*/


//insert the path to your crosswalks directory.
global crosswalks "..."

//insert the path for your output files (the do-file will create several .dta files along the way - one for each classification).
global output "..."

	
//from ISCO-88 to KZiS 04
use "$output\isco88.dta", clear
	joinby isco88 using "$crosswalks\isco88_kzis04.dta"
	collapse (mean) t_* , by(kzis04)
	drop if kzis04==.
save "$output\kzis04.dta", replace

//from ISCO-08 to KZiS 10
use "$output\isco08.dta", clear
	joinby isco08 using "$crosswalks\isco08_kzis10.dta", unmatched(both)
	replace kzis10=isco08 if kzis10==. & _merge==1 
	drop if kzis10==.
	collapse (mean) t_* , by(kzis10)
save "$output\kzis10.dta", replace

//from KZiS 04 to KZiS 02
use "$output\kzis04.dta", clear
	joinby kzis04 using "$crosswalks\kzis04_kzis02.dta"
	collapse (mean) t_* , by(kzis02)
	drop if kzis02==.
save "$output\kzis02.dta", replace
	
//from KZiS 02 to KZiS 95
use "$output\kzis02.dta", clear
	joinby kzis02 using "$crosswalks\kzis02_kzis95.dta"
	collapse (mean) t_*, by(kzis95) 
	drop if kzis95==. 
save "$output\kzis95.dta", replace
	
